@@ -26,7 +26,6 @@ from jedi import (Script, create_environment,  # type: ignore
                   RefactoringError)
 from jedi.api.classes import Name, Completion  # type: ignore
 from jedi.api.refactoring import Refactoring  # type: ignore
-from parso import split_lines  # type: ignore
 
 from pycodestyle import (BaseReport as CodestyleBaseReport,  # type: ignore
                          Checker as CodestyleChecker,
@@ -36,17 +35,17 @@ from pyflakes.api import check as pyflakes_check  # type: ignore
 
 from yapf.yapflib.yapf_api import FormatCode  # type: ignore
 
-from pygls.features import (COMPLETION, TEXT_DOCUMENT_DID_CHANGE,
-                            TEXT_DOCUMENT_DID_CLOSE, TEXT_DOCUMENT_DID_OPEN,
-                            HOVER, SIGNATURE_HELP, DEFINITION,
-                            REFERENCES, WORKSPACE_DID_CHANGE_CONFIGURATION,
-                            TEXT_DOCUMENT_WILL_SAVE, TEXT_DOCUMENT_DID_SAVE,
-                            DOCUMENT_SYMBOL, CODE_ACTION, FORMATTING,
-                            RANGE_FORMATTING, RENAME, DOCUMENT_HIGHLIGHT)
-from pygls import types
+from pygls.lsp.methods import (COMPLETION, TEXT_DOCUMENT_DID_CHANGE,
+                               TEXT_DOCUMENT_DID_CLOSE, TEXT_DOCUMENT_DID_OPEN,
+                               HOVER, SIGNATURE_HELP, DEFINITION,
+                               REFERENCES, WORKSPACE_DID_CHANGE_CONFIGURATION,
+                               TEXT_DOCUMENT_WILL_SAVE, TEXT_DOCUMENT_DID_SAVE,
+                               DOCUMENT_SYMBOL, CODE_ACTION, FORMATTING,
+                               RANGE_FORMATTING, RENAME, DOCUMENT_HIGHLIGHT)
+from pygls.lsp import types
 from pygls.server import LanguageServer
 from pygls.protocol import LanguageServerProtocol
-from pygls.uris import from_fs_path, to_fs_path
+from pygls.uris import to_fs_path
 
 from .version import get_version  # type: ignore
 
@@ -86,9 +85,9 @@ class AnakinLanguageServerProtocol(LanguageServerProtocol):
         global documentSymbolFunction
         global hoverMarkup
         global hoverFunction
-        try:
-            venv = getattr(params.initializationOptions, 'venv', None)
-        except AttributeError:
+        if params.initialization_options:
+            venv = params.initialization_options.get('venv', None)
+        else:
             venv = None
         if venv:
             jediEnvironment = create_environment(venv, safe=False)
@@ -109,20 +108,20 @@ class AnakinLanguageServerProtocol(LanguageServerProtocol):
             except AttributeError:
                 return None
 
-        caps = getattr(params.capabilities, 'textDocument', None)
+        caps = getattr(params.capabilities, 'text_document', None)
 
-        if get_attr(caps, 'completion', 'completionItem', 'snippetSupport'):
+        if get_attr(caps, 'completion', 'completion_item', 'snippet_support'):
             completionFunction = _completions_snippets
         else:
             completionFunction = _completions
 
         if get_attr(caps,
-                    'documentSymbol', 'hierarchicalDocumentSymbolSupport'):
+                    'document_symbol', 'hierarchical_document_symbol_support'):
             documentSymbolFunction = _document_symbol_hierarchy
         else:
             documentSymbolFunction = _document_symbol_plain
 
-        hover = get_attr(caps, 'hover', 'contentFormat')
+        hover = get_attr(caps, 'hover', 'content_format')
         if hover:
             hoverMarkup = hover[0]
         if hoverMarkup == types.MarkupKind.Markdown:
@@ -130,20 +129,11 @@ class AnakinLanguageServerProtocol(LanguageServerProtocol):
         else:
             hoverFunction = _docstring
 
-        result.capabilities.textDocumentSync = types.TextDocumentSyncOptions(
-            open_close=True,
-            change=types.TextDocumentSyncKind.INCREMENTAL,
-            save=types.SaveOptions()
-        )
-        result.capabilities.codeActionProvider = types.CodeActionOptions([
-            types.CodeActionKind.RefactorInline,
-            types.CodeActionKind.RefactorExtract
-        ])
         # pygls does not currently support serverInfo of LSP v3.15
-        result.serverInfo = {
-            'name': 'anakinls',
-            'version': get_version(),
-        }
+        result.server_info = types.ServerInfo(
+            name='anakinls',
+            version=get_version(),
+        )
         return result
 
 
@@ -202,9 +192,10 @@ class PyflakesReporter:
 
     def unexpectedError(self, _filename, msg):
         self.result.append(types.Diagnostic(
-            types.Range(types.Position(), types.Position()),
-            msg,
-            types.DiagnosticSeverity.Error,
+            range=types.Range(start=types.Position(line=0, character=0),
+                              end=types.Position(line=0, character=0)),
+            message=msg,
+            severity=types.DiagnosticSeverity.Error,
             source='pyflakes'
         ))
 
@@ -215,12 +206,13 @@ class PyflakesReporter:
         line = lineno - 1
         col = offset or 0
         self.result.append(types.Diagnostic(
-            types.Range(
-                types.Position(line, col),
-                types.Position(line, len(self._get_codeline(line)) - col)
-            ),
-            msg,
-            types.DiagnosticSeverity.Error,
+            range=types.Range(
+                start=types.Position(line=line, character=col),
+                end=types.Position(
+                    line=line,
+                    character=len(self._get_codeline(line)) - col)),
+            message=msg,
+            severity=types.DiagnosticSeverity.Error,
             source='pyflakes'
         ))
 
@@ -231,12 +223,12 @@ class PyflakesReporter:
         else:
             severity = types.DiagnosticSeverity.Warning
         self.result.append(types.Diagnostic(
-            types.Range(
-                types.Position(line, message.col),
-                types.Position(line, len(self._get_codeline(line)))
-            ),
-            message.message % message.message_args,
-            severity,
+            range=types.Range(
+                start=types.Position(line=line, character=message.col),
+                end=types.Position(line=line,
+                                   character=len(self._get_codeline(line)))),
+            message=message.message % message.message_args,
+            severity=severity,
             source='pyflakes'
         ))
 
@@ -253,14 +245,16 @@ class CodestyleReport(CodestyleBaseReport):
             return
         line = line_number - 1
         self.result.append(types.Diagnostic(
-            types.Range(
-                types.Position(line, offset),
-                types.Position(line, len(self.lines[line].rstrip('\n\r')))
+            range=types.Range(
+                start=types.Position(line=line, character=offset),
+                end=types.Position(
+                    line=line,
+                    character=len(self.lines[line].rstrip('\n\r')))
             ),
-            text,
-            types.DiagnosticSeverity.Warning,
-            code,
-            'pycodestyle'
+            message=text,
+            severity=types.DiagnosticSeverity.Warning,
+            code=code,
+            source='pycodestyle'
         ))
 
 
@@ -343,12 +337,13 @@ def _mypy_check(ls: LanguageServer, uri: str, script: Script,
             severity = types.DiagnosticSeverity.Warning
         result.append(
             types.Diagnostic(
-                types.Range(
-                    types.Position(row, column),
-                    types.Position(row, len(script._code_lines[row]))
-                ),
-                message.strip(),
-                severity,
+                range=types.Range(
+                    start=types.Position(line=row, character=column),
+                    end=types.Position(
+                        line=row,
+                        character=len(script._code_lines[row]))),
+                message=message.strip(),
+                severity=severity,
                 source='mypy'
             )
         )
@@ -362,12 +357,14 @@ def _validate(ls: LanguageServer, uri: str, script: Script = None):
     # Jedi
     result = [
         types.Diagnostic(
-            types.Range(
-                types.Position(x.line - 1, x.column),
-                types.Position(x.until_line - 1, x.until_column)
+            range=types.Range(
+                start=types.Position(line=x.line - 1,
+                                     character=x.column),
+                end=types.Position(line=x.until_line - 1,
+                                   character=x.until_column)
             ),
-            x.get_message(),
-            types.DiagnosticSeverity.Error,
+            message=x.get_message(),
+            severity=types.DiagnosticSeverity.Error,
             source='jedi'
         )
         for x in script.get_syntax_errors()
@@ -401,22 +398,22 @@ def _validate(ls: LanguageServer, uri: str, script: Script = None):
 @server.feature(TEXT_DOCUMENT_DID_OPEN)
 def did_open(ls: LanguageServer, params: types.DidOpenTextDocumentParams):
     if config['diagnostic_on_open']:
-        _validate(ls, params.textDocument.uri)
+        _validate(ls, params.text_document.uri)
 
 
 @server.feature(TEXT_DOCUMENT_DID_CLOSE)
 def did_close(ls: LanguageServer, params: types.DidCloseTextDocumentParams):
     try:
-        del scripts[params.textDocument.uri]
+        del scripts[params.text_document.uri]
     except KeyError:
         pass
 
 
 @server.feature(TEXT_DOCUMENT_DID_CHANGE)
 def did_change(ls: LanguageServer, params: types.DidChangeTextDocumentParams):
-    script = get_script(ls, params.textDocument.uri, True)
+    script = get_script(ls, params.text_document.uri, True)
     if config['diagnostic_on_change']:
-        _validate(ls, params.textDocument.uri, script)
+        _validate(ls, params.text_document.uri, script)
 
 
 def _completion_sort_key(completion: Completion, prefix: str = '') -> str:
@@ -436,14 +433,16 @@ def _completion_item(completion: Completion, r: types.Range) -> Dict:
         lnm = 0
         label = label[1:]
     elif lnm:
-        _r = types.Range(types.Position(r.start.line, r.start.character - lnm),
-                         r.end)
+        _r = types.Range(
+            start=types.Position(line=r.start.line,
+                                 character=r.start.character - lnm),
+            end=r.end)
     return dict(
         label=label,
         kind=_COMPLETION_TYPES.get(completion.type,
                                    types.CompletionItemKind.Text),
         documentation=completion.docstring(raw=True),
-        text_edit=types.TextEdit(_r, label)
+        text_edit=types.TextEdit(range=_r, new_text=label)
     )
 
 
@@ -498,9 +497,10 @@ def _completions_snippets(completions: List[Completion],
             ))
 
 
-@server.feature(COMPLETION, trigger_characters=['.'])
+@server.feature(COMPLETION, types.CompletionOptions(trigger_characters=['.']))
 def completions(ls: LanguageServer, params: types.CompletionParams):
-    script = get_script(ls, params.textDocument.uri)
+    global completionFunction
+    script = get_script(ls, params.text_document.uri)
     completions = script.complete(
         params.position.line + 1,
         params.position.character,
@@ -513,13 +513,13 @@ def completions(ls: LanguageServer, params: types.CompletionParams):
     else:
         word_rest = 0
     r = types.Range(
-        types.Position(params.position.line,
-                       params.position.character),
-        types.Position(params.position.line,
-                       params.position.character + word_rest)
+        start=types.Position(line=params.position.line,
+                             character=params.position.character),
+        end=types.Position(line=params.position.line,
+                           character=params.position.character + word_rest)
     )
-    return types.CompletionList(False,
-                                list(completionFunction(completions, r)))
+    return types.CompletionList(is_incomplete=False,
+                                items=list(completionFunction(completions, r)))
 
 
 def _docstring(name: Name) -> str:
@@ -546,24 +546,27 @@ def _docstring_markdown(name: Name) -> str:
 @server.feature(HOVER)
 def hover(ls: LanguageServer,
           params: types.TextDocumentPositionParams) -> Optional[types.Hover]:
-    script = get_script(ls, params.textDocument.uri)
+    global hoverFunction
+    global jediHoverFunction
+    script = get_script(ls, params.text_document.uri)
     names = jediHoverFunction(script,
                               params.position.line + 1,
                               params.position.character)
     result = '\n\n'.join(map(hoverFunction, names))
     if result:
         return types.Hover(
-            types.MarkupContent(hoverMarkup, result)
+            contents=types.MarkupContent(kind=hoverMarkup, value=result)
         )
     return None
 
 
-@server.feature(SIGNATURE_HELP, trigger_characters=['(', ','])
+@server.feature(SIGNATURE_HELP,
+                types.SignatureHelpOptions(trigger_characters=['(', ',']))
 def signature_help(
         ls: LanguageServer,
         params: types.TextDocumentPositionParams
 ) -> Optional[types.SignatureHelp]:
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     signatures = script.get_signatures(params.position.line + 1,
                                        params.position.character)
 
@@ -575,9 +578,9 @@ def signature_help(
         if signature.index is None:
             continue
         result.append(types.SignatureInformation(
-            signature.to_string(),
+            label=signature.to_string(),
             parameters=[
-                types.ParameterInformation(param.name)
+                types.ParameterInformation(label=param.name)
                 for param in signature.params
             ]
         ))
@@ -586,22 +589,26 @@ def signature_help(
             idx = i
         i += 1
     if result:
-        return types.SignatureHelp([result[idx]], 0, param_idx)
+        return types.SignatureHelp(
+            signatures=[result[idx]],
+            active_signature=0,
+            active_parameter=param_idx)
     return None
 
 
 def _get_name_range(name: Name) -> types.Range:
     return types.Range(
-        types.Position(name.line - 1, name.column),
-        types.Position(name.line - 1, name.column + len(name.name))
+        start=types.Position(line=name.line - 1, character=name.column),
+        end=types.Position(line=name.line - 1,
+                           character=name.column + len(name.name))
     )
 
 
 def _get_locations(defs: List[Name]) -> List[types.Location]:
     return [
         types.Location(
-            from_fs_path(str(d.module_path)),
-            _get_name_range(d)
+            uri=d.module_path.absolute().as_uri(),
+            range=_get_name_range(d)
         )
         for d in defs if d.module_path
     ]
@@ -611,7 +618,7 @@ def _get_locations(defs: List[Name]) -> List[types.Location]:
 def definition(
         ls: LanguageServer,
         params: types.TextDocumentPositionParams) -> List[types.Location]:
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     defs = script.goto(params.position.line + 1, params.position.character)
     return _get_locations(defs)
 
@@ -619,7 +626,7 @@ def definition(
 @server.feature(REFERENCES)
 def references(ls: LanguageServer,
                params: types.ReferenceParams) -> List[types.Location]:
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     refs = script.get_references(params.position.line + 1,
                                  params.position.character)
     return _get_locations(refs)
@@ -628,33 +635,34 @@ def references(ls: LanguageServer,
 @server.feature(WORKSPACE_DID_CHANGE_CONFIGURATION)
 def did_change_configuration(ls: LanguageServer,
                              settings: types.DidChangeConfigurationParams):
-    if not settings.settings or not hasattr(settings.settings, 'anakinls'):
+    if not settings.settings or 'anakinls' not in settings.settings:
         return
+    conf = settings.settings['anakinls']
     changed = set()
     for k in config:
-        if hasattr(settings.settings.anakinls, k):
-            config[k] = v = getattr(settings.settings.anakinls, k)
-            if k == 'help_on_hover':
-                global jediHoverFunction
-                if v:
-                    jediHoverFunction = Script.help
-                else:
-                    jediHoverFunction = Script.infer
-            elif k == 'completion_snippet_first':
-                global completionPrefixPlain
-                global completionPrefixSnippet
-                if v:
-                    completionPrefixPlain = 'z'
-                    completionPrefixSnippet = 'a'
-                else:
-                    completionPrefixPlain = 'a'
-                    completionPrefixSnippet = 'z'
+        if k not in conf:
+            continue
+        config[k] = v = conf[k]
+        if k == 'help_on_hover':
+            global jediHoverFunction
+            if v:
+                jediHoverFunction = Script.help
             else:
-                changed.add(k)
-    if hasattr(settings.settings.anakinls, 'jedi_settings'):
-        for k in settings.settings.anakinls.jedi_settings._fields:
-            v = getattr(settings.settings.anakinls.jedi_settings, k)
-            setattr(jedi_settings, k, v)
+                jediHoverFunction = Script.infer
+        elif k == 'completion_snippet_first':
+            global completionPrefixPlain
+            global completionPrefixSnippet
+            if v:
+                completionPrefixPlain = 'z'
+                completionPrefixSnippet = 'a'
+            else:
+                completionPrefixPlain = 'a'
+                completionPrefixSnippet = 'z'
+        else:
+            changed.add(k)
+    if 'jedi_settings' in conf:
+        for key, value in conf['jedi_settings'].items():
+            setattr(jedi_settings, key, value)
 
     if 'pycodestyle_config' in changed:
         pycodestyleOptions.clear()
@@ -670,10 +678,11 @@ def will_save(ls: LanguageServer, params: types.WillSaveTextDocumentParams):
     pass
 
 
-@server.feature(TEXT_DOCUMENT_DID_SAVE)
+@server.feature(TEXT_DOCUMENT_DID_SAVE,
+                types.TextDocumentSaveRegistrationOptions(include_text=False))
 def did_save(ls: LanguageServer, params: types.DidSaveTextDocumentParams):
     if config['diagnostic_on_save']:
-        _validate(ls, params.textDocument.uri)
+        _validate(ls, params.text_document.uri)
 
 
 _DOCUMENT_SYMBOL_KINDS = {
@@ -707,14 +716,14 @@ def _get_document_symbols(
         )
         line = name.line - 1
         r = types.Range(
-            types.Position(line, name.column),
-            types.Position(line, len(code_lines[line]) - 1)
+            start=types.Position(line=line, character=name.column),
+            end=types.Position(line=line, character=len(code_lines[line]) - 1)
         )
         result.append(types.DocumentSymbol(
-            name.name,
-            _DOCUMENT_SYMBOL_KINDS.get(name.type, types.SymbolKind.Null),
-            r,
-            r,
+            name=name.name,
+            kind=_DOCUMENT_SYMBOL_KINDS.get(name.type, types.SymbolKind.Null),
+            range=r,
+            selection_range=r,
             children=children or None
         ))
     return result
@@ -742,14 +751,16 @@ def _document_symbol_plain(
                 elif parent_name.startswith(f'{module_name}.'):
                     parent_name = parent_name[len(module_name) + 1:]
             yield types.SymbolInformation(
-                name.name,
-                _DOCUMENT_SYMBOL_KINDS.get(name.type, types.SymbolKind.Null),
-                types.Location(uri, types.Range(
-                    types.Position(name.line - 1, name.column),
-                    types.Position(name.line - 1,
-                                   len(code_lines[name.line - 1]) - 1)
-                )),
-                parent_name
+                name=name.name,
+                kind=_DOCUMENT_SYMBOL_KINDS.get(name.type,
+                                                types.SymbolKind.Null),
+                location=types.Location(uri=uri, range=types.Range(
+                    start=types.Position(line=name.line - 1,
+                                         character=name.column),
+                    end=types.Position(
+                        line=name.line - 1,
+                        characret=len(code_lines[name.line - 1]) - 1))),
+                container_name=parent_name
             )
     return list(_symbols())
 
@@ -758,22 +769,21 @@ def _document_symbol_plain(
 def document_symbol(
         ls: LanguageServer, params: types.DocumentSymbolParams
 ) -> Union[List[types.DocumentSymbol], List[types.SymbolInformation], None]:
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     names = script.get_names(all_scopes=True)
     if not names:
         return None
+    global documentSymbolFunction
     result = documentSymbolFunction(
-        params.textDocument.uri,
+        params.text_document.uri,
         script._code_lines,
         script.get_names(all_scopes=True)
     )
     return result
 
 
-def _get_text_edits(old: str, new: str) -> List[types.TextEdit]:
+def _get_text_edits(diff: str) -> List[types.TextEdit]:
     result = []
-    old_lines = split_lines(old, keepends=True)
-    new_lines = split_lines(new, keepends=True)
     line_number = 0
     start = None
     replace_lines = False
@@ -781,37 +791,36 @@ def _get_text_edits(old: str, new: str) -> List[types.TextEdit]:
 
     def _append():
         if replace_lines:
-            end = types.Position(line_number)
+            end = types.Position(line=line_number, character=0)
         else:
             end = start
         result.append(
             types.TextEdit(
-                types.Range(start, end),
-                ''.join(lines)
-            )
-        )
+                range=types.Range(start=start, end=end),
+                new_text=''.join(lines)))
 
-    for line in differ.compare(old_lines, new_lines):
+    for line in diff.splitlines(True)[2:]:
         kind = line[0]
-        if kind == '?':
-            continue
         if kind == '-':
             if not start:
-                start = types.Position(line_number)
+                start = types.Position(line=line_number, character=0)
             replace_lines = True
             line_number += 1
             continue
         if kind == '+':
             if not start:
-                start = types.Position(line_number)
-            lines.append(line[2:])
+                start = types.Position(line=line_number, character=0)
+            lines.append(line[1:])
             continue
         if start:
             _append()
             start = None
             replace_lines = False
             lines = []
-        line_number += 1
+        if kind == '@':
+            line_number = int(line[4:line.index(',')]) - 1
+        else:
+            line_number += 1
     if start:
         _append()
     return result
@@ -822,28 +831,30 @@ def _get_document_changes(
 ) -> List[types.TextDocumentEdit]:
     result = []
     for fn, changes in refactoring.get_changed_files().items():
-        text_edits = _get_text_edits(changes._module_node.get_code(),
-                                     changes.get_new_code())
+        text_edits = _get_text_edits(changes.get_diff())
         if text_edits:
-            uri = from_fs_path(str(fn))
+            uri = fn.absolute().as_uri()
             result.append(types.TextDocumentEdit(
-                types.VersionedTextDocumentIdentifier(
-                    uri,
-                    ls.workspace.get_document(uri).version
+                text_document=types.VersionedTextDocumentIdentifier(
+                    uri=uri,
+                    version=ls.workspace.get_document(uri).version
                 ),
-                text_edits
+                edits=text_edits
             ))
     return result
 
 
-@server.feature(CODE_ACTION)
+@server.feature(CODE_ACTION, types.CodeActionOptions(
+    code_action_kinds=[
+        types.CodeActionKind.RefactorInline,
+        types.CodeActionKind.RefactorExtract]))
 def code_action(
         ls: LanguageServer, params: types.CodeActionParams
 ) -> Optional[List[types.CodeAction]]:
     if params.range.start != params.range.end:
         # No selection actions
         return None
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     try:
         refactoring = script.inline(params.range.start.line + 1,
                                     params.range.start.character)
@@ -852,8 +863,8 @@ def code_action(
     document_changes = _get_document_changes(ls, refactoring)
     if document_changes:
         return [types.CodeAction(
-            'Inline variable',
-            types.CodeActionKind.RefactorInline,
+            title='Inline variable',
+            kind=types.CodeActionKind.RefactorInline,
             edit=types.WorkspaceEdit(document_changes=document_changes))]
     return None
 
@@ -863,33 +874,35 @@ def _formatting(
 ) -> Optional[List[types.TextEdit]]:
     old = get_script(ls, uri)._code
     lines = [(range_.start.line + 1, range_.end.line + 1)] if range_ else None
-    new, changed = FormatCode(old, style_config=config['yapf_style_config'],
-                              lines=lines)
-    return _get_text_edits(old, new) if changed else None
+    diff, changed = FormatCode(old, style_config=config['yapf_style_config'],
+                               lines=lines, print_diff=True)
+    if not changed:
+        return None
+    return _get_text_edits(diff)
 
 
 @server.feature(FORMATTING)
 def formatting(
         ls: LanguageServer, params: types.DocumentFormattingParams
 ) -> Optional[List[types.TextEdit]]:
-    return _formatting(ls, params.textDocument.uri)
+    return _formatting(ls, params.text_document.uri)
 
 
 @server.feature(RANGE_FORMATTING)
 def range_formatting(
         ls: LanguageServer, params: types.DocumentRangeFormattingParams
 ) -> Optional[List[types.TextEdit]]:
-    return _formatting(ls, params.textDocument.uri, params.range)
+    return _formatting(ls, params.text_document.uri, params.range)
 
 
 @server.feature(RENAME)
 def rename(ls: LanguageServer,
            params: types.RenameParams) -> Optional[types.WorkspaceEdit]:
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     try:
         refactoring = script.rename(params.position.line + 1,
                                     params.position.character,
-                                    new_name=params.newName)
+                                    new_name=params.new_name)
     except RefactoringError:
         return None
     document_changes = _get_document_changes(ls, refactoring)
@@ -902,7 +915,7 @@ def rename(ls: LanguageServer,
 def highlight(
         ls: LanguageServer, params: types.TextDocumentPositionParams
 ) -> Optional[List[types.DocumentHighlight]]:
-    script = get_script(ls, params.textDocument.uri)
+    script = get_script(ls, params.text_document.uri)
     names = script.get_references(params.position.line + 1,
                                   params.position.character,
                                   scope='file')
@@ -910,7 +923,7 @@ def highlight(
         return None
     return [
         types.DocumentHighlight(
-            _get_name_range(name)
+            range=_get_name_range(name)
         )
         for name in names
     ]
